==> frotz_2.53+dfsg.orig.tar.xz: frotz-2.53/README.md <==
# FROTZ V2.52
An interpreter for all Infocom and other Z-machine games.
Complies with standard 1.0 of Graham Nelson's specification.

Originally written by Stefan Jokisch in 1995-1997.
Ported to Unix by Galen Hazelwood.
Reference code and Unix port currently maintained by David Griffith.

## Features
- Compiles and runs on most common flavors of Unix, both open source and not.
  This includes macOS.
- Portable to many other operating systems and hardware.
- Curses, Dumb, and SDL user interfaces.
- Plays all Z-code games including V6.
- Sound support through libao.
- Graphics displayed through SDL.
- Config files.
- User-configurable error checking.
- Distributed under the GNU Public License, version 2 or any later version.

## Information
For information on what Interactive Fiction is and how to play it, see the
file "HOW_TO_PLAY".

For installation information, see the file "INSTALL".

For information on building for DOS, see the file "DOSBUILD.txt".

For update history, see the file "Changelog".

For information on known bugs in Frotz, see the file "BUGS".

The Frotz homepage is at https://661.org/proj/if/frotz/

The latest information on and source code of Unix Frotz is available at 
https://gitlab.com/DavidGriffith/frotz

## Downloads
The latest release of Unix Frotz is available from the Interactive
Fiction Archive at:  
http://www.ifarchive.org/if-archive/infocom/interpreters/frotz/  
and  
ftp://ftp.ifarchive.org/if-archive/infocom/interpreters/frotz/  


## Mirrors
The Interactive Fiction Archive has several mirrors which may be better
choices depending on where you live.

- USA: http://ifarchive.jmac.org
- USA: http://ifmirror.russotto.net
- USA: http://ifarchive.smallwhitehouse.org
- USA: http://ifarchive.info
- USA: http://ifarchive.ifreviews.org
- USA: ftp://ifarchive.ifreviews.org
- USA: http://mirrors.ibiblio.org/interactive-fiction/
- USA: gopher://gopher.661.org/1/if-archive

==> frotz_2.54+dfsg.orig.tar.xz: frotz-2.54/README.md <==
# FROTZ V2.54
An interpreter for all Infocom and other Z-machine games.
Complies with standard 1.0 of Graham Nelson's specification.

[![Liberapay](https://img.shields.io/liberapay/receives/DavidG.svg?logo=liberapay)](https://liberapay.com/DavidG)

Originally written by Stefan Jokisch in 1995-1997.
Ported to Unix by Galen Hazelwood.
Reference code and Unix port currently maintained by David Griffith.

## Features
- Compiles and runs on most common flavors of Unix, both open source and not.
  This includes macOS.
- Compiles and runs on MSDOS/PCDOS/FreeDOS.
- Compiles and runs on PDP-10 mainframes running the TOPS20 operating system.
- Portable to many other operating systems and hardware.
- Curses, Dumb, and SDL user interfaces.
- Plays all Z-code games including V6.
- Sound support through libao.
- Graphics displayed through SDL.
- Config files.
- User-configurable error checking.
- Distributed under the GNU Public License, version 2 or any later version.

## Information
For information on what Interactive Fiction is and how to play it, see the
file "HOW_TO_PLAY".

For installation information, see the file "INSTALL".

For information on building for DOS, see the file "INSTALL_DOS".

For information on building for TOPS20, see the file "INSTALL_PDP10".

For update history, see the file "Changelog".

For information on known bugs in Frotz, see the file "BUGS".

The Frotz homepage is at https://661.org/proj/if/frotz/

The latest information on and source code of Unix Frotz is available at 
https://gitlab.com/DavidGriffith/frotz

## Downloads
The latest release of Unix Frotz is available from the Interactive
Fiction Archive at:  
http://www.ifarchive.org/if-archive/infocom/interpreters/frotz/  
and  
ftp://ftp.ifarchive.org/if-archive/infocom/interpreters/frotz/  


## Mirrors
The Interactive Fiction Archive has several mirrors which may be better
choices depending on where you live.

- USA: http://ifarchive.jmac.org
- USA: http://ifmirror.russotto.net
- USA: http://ifarchive.smallwhitehouse.org
- USA: http://ifarchive.info
- USA: http://ifarchive.ifreviews.org
- USA: ftp://ifarchive.ifreviews.org
- USA: http://mirrors.ibiblio.org/interactive-fiction/
- USA: gopher://gopher.661.org/1/if-archive
